####Organizing data in 2 weeks intervals
library(plyr)
library(dplyr)
library(stringr)
library(ISOweek)
library(stringi)
library(geosphere)
#setwd("C:/neonTeaching")
load('MammalsData.RData')


Mams.Count<-MammalsData$mam_pertrapnight


Mams.Count<-dplyr::select(Mams.Count, nightuid, siteID, plotID, domainID, plotType,trapCoordinate,trapStatus,#I dont really need namedlocation, domainID and siteID
               endDate, collectDate, scientificName, taxonRank, recapture, tagID)

##Getting year/month for each sample as well as trap status
Mams.Count["Year"]<-substr(x = Mams.Count$endDate, start = 1, stop = 4) 
Mams.Count["YearMonth"]<-substr(x = Mams.Count$endDate, start = 1, stop = 7) 
Mams.Count$trapStatus<-word(string = Mams.Count$trapStatus, start = 1, end = 1) ##I'll use only traps with 4-6 values

MamsStand<-vector(mode='list',length = length(unique(Mams.Count$collectDate)))

for(i in 1:length(MamsStand)){##i = 238, 474, 555 with different data/year
  Dado.Sem<-Mams.Count[which(Mams.Count$collectDate==unique(Mams.Count$collectDate)[i]),]
  
  Site.List<-vector(mode='list',length = length(unique(Dado.Sem$siteID)))
  
  for(j in 1:length(unique(Dado.Sem$siteID))){
    Site.Data<-Dado.Sem[which(Dado.Sem$siteID==unique(Dado.Sem$siteID)[j]),]
    CMams<-na.omit(dplyr::count(Site.Data,siteID,scientificName))
    if(nrow(CMams)==0){
      next()
    }
    CMams['domainID']<-unique(Site.Data$domainID)

    CMams['Year']<-unique(Site.Data$Year)
    CMams['YearMonth']<-unique(Site.Data$YearMonth)
    CMams['Week']<-unique(Site.Data$collectDate)
    Site.List[[j]]<-CMams
  }
  MamsStand[[i]]<-do.call(rbind, Site.List)
  print(i)
  
}


MamsStand<-do.call(rbind, MamsStand)

###Lets separate the data for each sites spatial

##Use all species and the east gradient. Include Hawaaii
#E.Sites<-c('DSNY','MLBS', 'SERC', 'BLAN','HARV','BART','TOOL','JORN','MOAB')##TOOL = Alaska
E.Sites<-unique(MamsStand$siteID)##TOOL = Alaska
E.Sites<-E.Sites[-which(E.Sites%in%c("GUAN", "LAJA"))] ## Because they are not sampled in 2019
setwd("C:/neonTeaching")
library(funrar)
neonTeaching.Spatial<-MamsStand[which(MamsStand$siteID%in%E.Sites & MamsStand$Year==2019),]
neonTeaching.Spatial<-aggregate(n~scientificName+siteID, data = neonTeaching.Spatial, sum)
neonTeaching.Spatial<-dplyr::filter(neonTeaching.Spatial, !grepl('/|sp\\.|spp\\.|cx\\.|gr\\.|/', scientificName))
neonTeaching.Spatial.Table<-stack_to_matrix(my_df = neonTeaching.Spatial, col_to_row = 'scientificName',
                                            col_to_col = 'siteID',col_value = 'n')
# set.seed(1)
# neonTeaching.Spatial.Table<-neonTeaching.Spatial.Table[sample(x = nrow(neonTeaching.Spatial.Table), size = 41, replace = FALSE),]
neonTeaching.Spatial.Table[is.na(neonTeaching.Spatial.Table)]<-0
neonTeaching.Spatial.Table<-as.data.frame(neonTeaching.Spatial.Table)
neonTeaching.Spatial.Table['Species']<-rownames(neonTeaching.Spatial.Table)
rownames(neonTeaching.Spatial.Table)<-NULL
neonTeaching.Spatial.Table<-select(.data = neonTeaching.Spatial.Table, Species, everything())

##Putting species in columns and sites in rows
neonTeaching.Spatial.Table<-as.data.frame(t(neonTeaching.Spatial.Table))
colnames(neonTeaching.Spatial.Table)<-neonTeaching.Spatial.Table[1,]
neonTeaching.Spatial.Table<-neonTeaching.Spatial.Table[-1,]
Sites<-rownames(neonTeaching.Spatial.Table)
neonTeaching.Spatial.Table<-apply(X = neonTeaching.Spatial.Table, MARGIN = 2, FUN = as.numeric)
rownames(neonTeaching.Spatial.Table)<-Sites
write.csv(x = neonTeaching.Spatial.Table, file = 'Spatial.csv')

###Temporal
#Sampling.sites<-c('TOOL','JORN','MOAB','BART')
neonTeaching.Temporal<-MamsStand[which(MamsStand$siteID%in%E.Sites & MamsStand$Year%in%c(2014:2019)),]
neonTeaching.Temporal<-dplyr::filter(neonTeaching.Temporal, !grepl('/|sp\\.|spp\\.|cx\\.|gr\\.|/', scientificName))
neonTeaching.Temporal.Mat<-stack_to_matrix(my_df = neonTeaching.Temporal[which(neonTeaching.Temporal$siteID%in%E.Sites),],
                                           col_to_row = 'scientificName', col_to_col = 'Year', col_value = 'n')
# set.seed(1)
# neonTeaching.Temporal.Mat<-neonTeaching.Temporal.Mat[sample(x = nrow(neonTeaching.Temporal.Mat), size = 41, replace = FALSE),]
neonTeaching.Temporal.Mat[is.na(neonTeaching.Temporal.Mat)]<-0
neonTeaching.Temporal.Mat<-as.data.frame(neonTeaching.Temporal.Mat)
neonTeaching.Temporal.Mat['Species']<-rownames(neonTeaching.Temporal.Mat)
rownames(neonTeaching.Temporal.Mat)<-NULL
neonTeaching.Temporal.Mat<-neonTeaching.Temporal.Mat[,c(7,1:6)]



###Saving the temporal dataset
for(j in 1:length(E.Sites)){
  neonTeaching.Temporal.Site<-neonTeaching.Temporal.Mat
  neonTeaching.Temporal.Site[,2:4]<-0
  
  for(i in 2:ncol(neonTeaching.Temporal.Site)){
    Site<-neonTeaching.Temporal[which(neonTeaching.Temporal$siteID==E.Sites[j] & neonTeaching.Temporal$Year==colnames(neonTeaching.Temporal.Site)[i]),]
    neonTeaching.Temporal.Site[,i]<-Site[match(neonTeaching.Temporal.Site$Species,Site$scientificName),'n']
  }
  neonTeaching.Temporal.Site[is.na(neonTeaching.Temporal.Site)]<-0
  ##Putting years in rows
  neonTeaching.Temporal.Site<-as.data.frame(t(neonTeaching.Temporal.Site))
  colnames(neonTeaching.Temporal.Site)<-neonTeaching.Temporal.Site[1,]
  neonTeaching.Temporal.Site<-neonTeaching.Temporal.Site[-1,]
  Years<-rownames(neonTeaching.Temporal.Site)
  neonTeaching.Temporal.Site<-apply(X = neonTeaching.Temporal.Site, MARGIN = 2, FUN = as.numeric)
  rownames(neonTeaching.Temporal.Site)<-Years
  write.csv(x = neonTeaching.Temporal.Site, file = paste0('Temporal_',paste(E.Sites[j]),paste('.csv')), row.names = TRUE)
}

##Getting the mean latitude for each site


Latitudes<-aggregate(decimalLatitude~siteID, data = MammalsData$mam_pertrapnight, FUN = mean)
Longitudes<-aggregate(decimalLongitude~siteID, data = MammalsData$mam_pertrapnight, FUN = mean)
LongLat<-Longitudes
LongLat['Latitude']<-Latitudes$decimalLatitude

Latitudes<-Latitudes[which(Latitudes$siteID%in%E.Sites),]
colnames(Latitudes)<-c('siteID','Latitude')
Latitudes[,2]<-round(Latitudes$Latitude,0)
Latitudes<-as.data.frame(t(Latitudes))
Latitudes[2,]<-as.numeric(Latitudes[2,])
write.csv(x = Latitudes, file = 'Latitudes.csv')

##Calculate the mean pairwise distance between sites

LongLat<-LongLat[which(LongLat$siteID%in%E.Sites),]
Distancias<-distm(LongLat[,2:3])/1000##Distance in KM
colnames(Distancias)<-LongLat$siteID
rownames(Distancias)<-LongLat$siteID
Distancias<-round(Distancias,0)
write.csv(Distancias, file = 'Distances_KM.csv')


## CREATE NEW COLUMN TO FIND WHETHER THE SPECIES WAS SAMPLED IN AT LEAST
#ONE OF THE YEARS THERE. tO FIND IT USE THIS COMMAND: '=IF(SUM(A2:C2)>=1;1;0)'


